@@ -48,6 +48,11 @@ service_mapping = {
         "API Gateway",
         "Developer Services"
     ],
+    "api-platform": [
+        "api_platform",
+        "P Control Plane",
+        "Others"
+    ],
     "apiaccesscontrol": [
         "apiaccesscontrol",
         "Oracle  Access Control",
@@ -493,6 +498,11 @@ service_mapping = {
         "Monitoring",
         "Others"
     ],
+    "multicloud": [
+        "multicloud",
+        "Oracle Multicloud",
+        "Others"
+    ],
     "mysql": [
         "mysql",
         "MySQL Database Service",
